fetch_datasets
===============================================================

.. currentmodule:: imbalanced_ensemble.datasets

.. autofunction:: fetch_datasets

.. include:: ../../../back_references/imbalanced_ensemble.datasets.fetch_datasets.examples

.. raw:: html

    <div style='clear:both'></div>